banshee r3256 - in trunk/banshee: . src/Extensions/Banshee.Lastfm/Banshee.Lastfm.Radio src/Libraries/Lastfm src/Libraries/Lastfm/Lastfm



Author: gburt
Date: Sun Feb 17 03:34:19 2008
New Revision: 3256
URL: http://svn.gnome.org/viewvc/banshee?rev=3256&view=rev

Log:
2008-02-16  Gabriel Burt  <gabriel burt gmail com>

	* src/Libraries/Lastfm/Lastfm/Connection.cs:
	* src/Libraries/Lastfm/Lastfm/RadioConnection.cs: Rename to
	RadioConnection.cs

	* src/Extensions/Banshee.Lastfm/Banshee.Lastfm.Radio/StationSource.cs: Use
	RadioConnection.


Added:
   trunk/banshee/src/Libraries/Lastfm/Lastfm/RadioConnection.cs
      - copied, changed from r3252, /trunk/banshee/src/Libraries/Lastfm/Lastfm/Connection.cs
Removed:
   trunk/banshee/src/Libraries/Lastfm/Lastfm/Connection.cs
Modified:
   trunk/banshee/ChangeLog
   trunk/banshee/src/Extensions/Banshee.Lastfm/Banshee.Lastfm.Radio/StationSource.cs
   trunk/banshee/src/Libraries/Lastfm/Lastfm.mdp
   trunk/banshee/src/Libraries/Lastfm/Makefile.am

Modified: trunk/banshee/src/Extensions/Banshee.Lastfm/Banshee.Lastfm.Radio/StationSource.cs
==============================================================================
--- trunk/banshee/src/Libraries/Lastfm/Lastfm.mdp	(original)
+++ trunk/banshee/src/Libraries/Lastfm/Lastfm.mdp	Sun Feb 17 03:34:19 2008
@@ -10,7 +10,7 @@
   <Contents>
     <File name="Lastfm/Account.cs" subtype="Code" buildaction="Compile" />
     <File name="Lastfm/Browser.cs" subtype="Code" buildaction="Compile" />
-    <File name="Lastfm/Connection.cs" subtype="Code" buildaction="Compile" />
+    <File name="Lastfm/RadioConnection.cs" subtype="Code" buildaction="Compile" />
   </Contents>
   <References>
     <ProjectReference type="Gac" localcopy="True" refto="System, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" />
@@ -18,4 +18,4 @@
     <ProjectReference type="Gac" localcopy="True" refto="gnome-sharp, Version=2.8.0.0, Culture=neutral, PublicKeyToken=35e10195dab3c99f" />
     <ProjectReference type="Project" localcopy="True" refto="Hyena" />
   </References>
-</Project>
\ No newline at end of file
+</Project>

Copied: trunk/banshee/src/Libraries/Lastfm/Lastfm/RadioConnection.cs (from r3252, /trunk/banshee/src/Libraries/Lastfm/Lastfm/Connection.cs)
==============================================================================
--- /trunk/banshee/src/Libraries/Lastfm/Lastfm/Connection.cs	(original)
+++ trunk/banshee/src/Libraries/Lastfm/Lastfm/RadioConnection.cs	Sun Feb 17 03:34:19 2008
@@ -1,5 +1,5 @@
 //
-// Connection.cs
+// RadioConnection.cs
 //
 // Authors:
 //   Gabriel Burt <gburt novell com>
@@ -76,9 +76,9 @@
         Unknown // not an official code, just the fall back
     }
 
-	public class Connection 
+	public class RadioConnection 
 	{
-		public delegate void StateChangedHandler (Connection connection, ConnectionStateChangedArgs args);
+		public delegate void StateChangedHandler (RadioConnection connection, ConnectionStateChangedArgs args);
 		public event StateChangedHandler StateChanged;
 
 		private ConnectionState state;
@@ -130,7 +130,7 @@
 			get { return station; }
 		}
 
-		public Connection (Account account, string user_agent)
+		public RadioConnection (Account account, string user_agent)
 		{
             this.account = account;
             this.user_agent = user_agent;

Modified: trunk/banshee/src/Libraries/Lastfm/Makefile.am
==============================================================================
--- trunk/banshee/src/Libraries/Lastfm/Makefile.am	(original)
+++ trunk/banshee/src/Libraries/Lastfm/Makefile.am	Sun Feb 17 03:34:19 2008
@@ -5,7 +5,7 @@
 SOURCES = \
 	Lastfm/Account.cs \
 	Lastfm/Browser.cs \
-	Lastfm/Connection.cs \
+	Lastfm/RadioConnection.cs \
 	Lastfm.Data/DataCore.cs \
 	Lastfm.Data/DataEntry.cs \
 	Lastfm.Data/DataEntryCollection.cs \



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/banshee/src/Extensions/Banshee.Lastfm/Banshee.Lastfm.Radio/StationSource.cs	(original)
+++ trunk/banshee/src/Extensions/Banshee.Lastfm/Banshee.Lastfm.Radio/StationSource.cs	Sun Feb 17 03:34:19 2008
@@ -243,10 +243,10 @@
                 Log.Debug (String.Format ("Successfully tuned Last.fm to {0}", station), null);
                 return true;
             } else {
-                Log.Debug (String.Format ("Failed to tune Last.fm to {0}", Name), Connection.ErrorMessageFor (error));
+                Log.Debug (String.Format ("Failed to tune Last.fm to {0}", Name), RadioConnection.ErrorMessageFor (error));
                 SetStatus (String.Format (
-                    // Translators: {0} is an error message sentence from Connection.cs.
-                    Catalog.GetString ("Failed to tune in station. {0}"), Connection.ErrorMessageFor (error)), true
+                    // Translators: {0} is an error message sentence from RadioConnection.cs.
+                    Catalog.GetString ("Failed to tune in station. {0}"), RadioConnection.ErrorMessageFor (error)), true
                 );
                 return false;
             }
@@ -400,7 +400,7 @@
                 }
             } else {
                 track_model.Clear ();
-                SetStatus (Connection.MessageFor (state), state != ConnectionState.Connecting);
+                SetStatus (RadioConnection.MessageFor (state), state != ConnectionState.Connecting);
                 OnUpdated ();
             }
         }

Modified: trunk/banshee/src/Libraries/Lastfm/Lastfm.mdp
==============================================================================